==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/libroccatwidget/roccat_macro_editor.h <==
#ifndef __ROCCAT_MACRO_EDITOR_H__
#define __ROCCAT_MACRO_EDITOR_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/roccat.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_TYPE (roccat_macro_editor_get_type())
#define ROCCAT_MACRO_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_TYPE, RoccatMacroEditor))
#define IS_ROCCAT_MACRO_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_TYPE))

typedef struct _RoccatMacroEditor RoccatMacroEditor;
typedef struct _RoccatMacroEditorPrivate RoccatMacroEditorPrivate;

struct _RoccatMacroEditor {
	GtkHPaned window;
	RoccatMacroEditorPrivate *priv;
};

GType roccat_macro_editor_get_type(void);
GtkWidget *roccat_macro_editor_new(void);

void roccat_macro_editor_clear(RoccatMacroEditor *macro_editor);
void roccat_macro_editor_add_macros(RoccatMacroEditor *macro_editor, RoccatMacros *macros);
RoccatMacros *roccat_macro_editor_get_macros(RoccatMacroEditor *macro_editor);

void roccat_macro_editor_set_modified(RoccatMacroEditor *macro_editor, gboolean state);
gboolean roccat_macro_editor_get_modified(RoccatMacroEditor *macro_editor);

G_END_DECLS

#endif

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/libroccatwidget/roccat_macro_editor.h <==
#ifndef __ROCCAT_MACRO_EDITOR_H__
#define __ROCCAT_MACRO_EDITOR_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_macros.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_TYPE (roccat_macro_editor_get_type())
#define ROCCAT_MACRO_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_TYPE, RoccatMacroEditor))
#define IS_ROCCAT_MACRO_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_TYPE))

typedef struct _RoccatMacroEditor RoccatMacroEditor;
typedef struct _RoccatMacroEditorPrivate RoccatMacroEditorPrivate;

struct _RoccatMacroEditor {
	GtkHPaned window;
	RoccatMacroEditorPrivate *priv;
};

GType roccat_macro_editor_get_type(void);
GtkWidget *roccat_macro_editor_new(void);

void roccat_macro_editor_clear(RoccatMacroEditor *macro_editor);
void roccat_macro_editor_add_macros(RoccatMacroEditor *macro_editor, RoccatMacros *macros);
RoccatMacros *roccat_macro_editor_get_macros(RoccatMacroEditor *macro_editor);

void roccat_macro_editor_set_modified(RoccatMacroEditor *macro_editor, gboolean state);
gboolean roccat_macro_editor_get_modified(RoccatMacroEditor *macro_editor);

G_END_DECLS

#endif
